@@ -80,7 +80,7 @@ use App::Dochazka::REST::Model::Shared qw(
 use App::Dochazka::REST::Model::Tempintvls;
 use App::Dochazka::REST::ResourceDefs;
 use App::Dochazka::REST::Shared qw( :ALL );  # all the shared_* functions
-use App::Dochazka::REST::Util::Holiday qw( holidays_in_daterange );
+use App::Dochazka::REST::Holiday qw( holidays_in_daterange );
 use Data::Dumper;
 use File::Path qw( mkpath rmtree );
 use Module::Runtime qw( use_module );
@@ -857,7 +857,7 @@ sub handler_post_component_path {
 
     # second pass
     # - check that entity is kosher
-    my $status = shared_entity_check( $self, 'path', 'source', 'acl' );
+    my $status = shared_entity_check( $self, 'path' );
     return $status unless $status->ok;
     my $context = $self->context;
     my $entity = $context->{'request_entity'};
@@ -871,6 +871,8 @@ sub handler_post_component_path {
     if ( $comp ) {
         return shared_update_component( $self, $comp, $entity );
     } else {
+        my $status = shared_entity_check( $self, 'path', 'source', 'acl' );
+        return $status unless $status->ok;
         return shared_insert_component( $self, $path, $entity );
     }
 }
@@ -1566,8 +1568,61 @@ sub handler_genreport {
     return $fail unless $path;
     delete $entity->{'path'};
 
+    # - if there is a 'parameters' property, check that it is a hashref
+    my $parameters;
+    if ( $entity->{'parameters'} ) {
+        $log->debug( "Vetting parameters: " . Dumper $entity->{'parameters'} ) ;
+        if ( ref( $entity->{'parameters'} ) ne 'HASH' ) {
+            $self->mrest_declare_status( 
+                code => 400, 
+                explanation => 'parameters must be given as key:value pairs'
+            );
+            return $fail;
+        }
+        # - convert $parameters hashref into @entity array for validation
+        my $count = 0;
+        foreach my $key ( keys %{ $entity->{'parameters'} } ) {
+            $parameters->[$count] = $key;
+            $count += 1;
+            $parameters->[$count] = $entity->{'parameters'}->{$key};
+            $count += 1;
+        }
+    }
+
+    # - if there is a validations property, convert it into a hashref
+    #   and check the parameters against it
+    if ( my $validations = $comp->{validations} ) { 
+        my $success = 1;
+        $comp->{validations} = eval $validations;
+        $log->debug( "Validations after eval: " . Dumper $comp->{validations} );
+        if ( ref( $comp->{validations} ) ne 'HASH' ) {
+            $self->mrest_declare_status(
+                code => 500,
+                explanation => "AGAAKH! validations is not a HASHREF: $validations"
+            );
+            $success = 0;
+        }
+        return $fail unless $success;
+        $parameters = {} if not defined $parameters;
+        $log->debug( "About to validate parameters: " . Dumper $parameters );
+        validate_with( 
+            params => $parameters,
+            spec => $comp->{'validations'},
+            on_fail => sub {
+                my $errmsg = shift;
+                $self->mrest_declare_status( code => 400, explanation => $errmsg );
+                $success = 0;
+            },
+        );
+        return $fail unless $success;
+    }
+
     # - generate report
-    return $CELL->status_ok( 'DISPATCH_GENERATED_REPORT', payload => $comp->generate( %$entity ) );
+    $parameters = [] if not defined $parameters;
+    return $CELL->status_ok( 
+        'DISPATCH_GENERATED_REPORT', 
+        payload => $comp->generate( my %paramhash = @$parameters )
+    );
 }
 
 
